@@ -7,7 +7,7 @@ use autodie;
 
 use Carp qw(confess);
 
-our $VERSION = '0.11.11';
+our $VERSION = '0.02';
 
 sub new {
   my $class = shift;
@@ -98,7 +98,7 @@ sub get {
     }
     $matrix{$elem_ids_o->{$element}} = \%new_row if %new_row;
   }
-  confess(join(', ', map("'$_'", sort(keys(%remaining_elements)))) . ": no rows for this elements")
+  confess(join(', ', map("'$_'", keys(%remaining_elements))) . ": no rows for these elements")
     if %remaining_elements;
 
   $self->{matrix}   = \%matrix;
@@ -150,7 +150,7 @@ Text::Table::Read::RelationOn::Tiny - Read binary "relation on (over) a set" fro
 
 =head1 VERSION
 
-Version 0.11.11
+Version 0.02
 
 
 =head1 SYNOPSIS
@@ -449,11 +449,6 @@ L<https://cpanratings.perl.org/d/Text-Table-Read-RelationOn-Tiny>
 
 L<https://metacpan.org/release/Text-Table-Read-RelationOn-Tiny>
 
-=item * GitHub Repository
-
-L<https://github.com/AAHAZRED/perl-Text-Table-Read-RelationOn-Tiny>
-
-
 =back
 
 
@@ -464,7 +459,7 @@ This software is Copyright (c) 2021 by Abdul al Hazred.
 
 This is free software, licensed under:
 
-  The Artistic License 2.0 (GPL Compatible)
+  GNU GENERAL PUBLIC LICENSE Version 2
 
 
 =cut
